==> jaxx-demo-2.5.8-sources.jar: jaxx/demo/component/jaxx/editor/BeanDoubleListDemo.java <==
package jaxx.demo.component.jaxx.editor;

/*
 * #%L
 * JAXX :: Demo
 * $Id:$
 * $HeadURL:$
 * %%
 * Copyright (C) 2008 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.LayoutManager;
import jaxx.demo.DemoPanel;
import jaxx.demo.entities.People;
import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXObjectDescriptor;
import jaxx.runtime.JAXXUtil;
import jaxx.runtime.swing.Table;
import jaxx.runtime.swing.editor.bean.BeanDoubleList;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class BeanDoubleListDemo extends DemoPanel {

    /*-----------------------------------------------------------------------*/
    /*------------------------- Other static fields -------------------------*/
    /*-----------------------------------------------------------------------*/

    private static final String $jaxxObjectDescriptor = "H4sIAAAAAAAAAJVTv28TMRj9cjRJkwAFIqoCBbUlK5eqGwqCQqOooPBDpENFljqx1Vzl+Izto5cF8SfwJ8DOgsTGhBiYGVgQ/wJCDKyIz05yScoh4Ia7kz+/9z0/v+/VV8hqBasHJI59FQkT9Jl/5+bu7v3OAeuaOtNdFUgTKhg+GQ+8NpRosq4NXG43Lbw6gle3wr4MBRNT6FoTitoMONM9xoyBi7OIrtbVVlKuxTJSY9ZEVBrri+/fvOf02UsPIJaobg6PsvI31OQkc03wAmrgDHZ6QqqciH2UoQKxj3pP2LUtTrS+R/rsMTyFfBNykigkM7D270d2HA4fSwOlSp31wwdEML5uYMOJpbjid8cUvltjNEAS/xYjoh5GHc6agTYWKqUjyxnI94ignCkDV/+fZnuInWKr7BCso6ilGQf1Ifrhu5rdWUgARZoQGriSghn17mDvIwIsw4LEy7owA8MY+JMYTO4p04asinAZtbV/T85DLA0zs3QkM5bQVX8ulj+9/fKmMQ6Kh73Ppm6dyjleoFShRIMD23phmJLIBLx6l8haGwqacRwSNwTLKcJaozKKw36nLdy3cH+b6B5SZPOf371f3Pt4DLwGFHlIaIPY/behYHoKXQg5jeWNTafo+OE8vk9ZbQZynAzCCH0/eY0SQ1Y6gaBo+fUYTVhOMSFR0il8+FFuvd4cG5FBYef+uH1iRvYR5ALBA8HczIzGIXVGSlKziIaT2KcNQsZ+i3IUv/PufSntpPM2PjsD6dhX48h+1pxw+1dxPGXk+QVItzAyyQQAAA==";
    private static final Log log = LogFactory.getLog(BeanDoubleListDemo.class);
    private static final long serialVersionUID = 1L;

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Internal states ---------------------------*/
    /*-----------------------------------------------------------------------*/

    private boolean allComponentsCreated;

    /*-----------------------------------------------------------------------*/
    /*------------------------ Protected components  ------------------------*/
    /*-----------------------------------------------------------------------*/

    protected BeanDoubleList doubleList;
    protected BeanDoubleListDemoHandler handler;

    /*-----------------------------------------------------------------------*/
    /*------------------------- Private components  -------------------------*/
    /*-----------------------------------------------------------------------*/

    private BeanDoubleListDemo $DemoPanel0 = this;
    private Table $Table0;

    /*-----------------------------------------------------------------------*/
    /*---------------------- Raw body code from script ----------------------*/
    /*-----------------------------------------------------------------------*/

    protected void $afterCompleteSetup() {
        handler.init();
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Constructors  ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public BeanDoubleListDemo() {
        $initialize();
    }

    public BeanDoubleListDemo(JAXXContext param0) {
        super(param0);
        $initialize();
    }

    public BeanDoubleListDemo(boolean param0) {
        super(param0);
        $initialize();
    }

    public BeanDoubleListDemo(JAXXContext param0, boolean param1) {
        super(param0 ,param1);
        $initialize();
    }

    public BeanDoubleListDemo(LayoutManager param0) {
        super(param0);
        $initialize();
    }

    public BeanDoubleListDemo(JAXXContext param0, LayoutManager param1) {
        super(param0 ,param1);
        $initialize();
    }

    public BeanDoubleListDemo(LayoutManager param0, boolean param1) {
        super(param0 ,param1);
        $initialize();
    }

    public BeanDoubleListDemo(JAXXContext param0, LayoutManager param1, boolean param2) {
        super(param0 ,param1 ,param2);
        $initialize();
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Statics methods ---------------------------*/
    /*-----------------------------------------------------------------------*/

    public static JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return JAXXUtil.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*-----------------------------------------------------------------------*/
    /*----------------------- Public acessor methods  -----------------------*/
    /*-----------------------------------------------------------------------*/

    public BeanDoubleList getDoubleList() {
        return doubleList;
    }

    public BeanDoubleListDemoHandler getHandler() {
        return handler;
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Protected acessors methods  ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected Table get$Table0() {
        return $Table0;
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Components creation methods ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected void createDoubleList() {
        $objectMap.put("doubleList", doubleList = new BeanDoubleList());
        
        doubleList.setName("doubleList");
    }

    protected void createHandler() {
        $objectMap.put("handler", handler = new BeanDoubleListDemoHandler(this));
    }

    /*-----------------------------------------------------------------------*/
    /*------------------------ Internal jaxx methods ------------------------*/
    /*-----------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
        // inline complete setup of $DemoPanel0
        add($Table0);
        // inline complete setup of $Table0
        $Table0.add(doubleList, new GridBagConstraints(0, 0, 1, 1, 1.0, 1.0, 10, 1, new Insets(3, 3, 3, 3), 0, 0));
        
        // apply 2 property setters
        doubleList.setBeanType(People.class);
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated) {
            return;
        }
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
        $objectMap.put("$DemoPanel0", $DemoPanel0);
        createHandler();
        // inline creation of $Table0
        $objectMap.put("$Table0", $Table0 = new Table());
        
        $Table0.setName("$Table0");
        createDoubleList();
        // inline creation of $DemoPanel0
        setName("$DemoPanel0");
        setLayout(new BorderLayout());
        
        $completeSetup();
    }

}

==> jaxx-demo-2.5.9-sources.jar: jaxx/demo/component/jaxx/editor/BeanDoubleListDemo.java <==
package jaxx.demo.component.jaxx.editor;

/*
 * #%L
 * JAXX :: Demo
 * $Id:$
 * $HeadURL:$
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.LayoutManager;
import jaxx.demo.DemoPanel;
import jaxx.demo.entities.People;
import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXObjectDescriptor;
import jaxx.runtime.JAXXUtil;
import jaxx.runtime.swing.Table;
import jaxx.runtime.swing.editor.bean.BeanDoubleList;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class BeanDoubleListDemo extends DemoPanel {

    /*-----------------------------------------------------------------------*/
    /*------------------------- Other static fields -------------------------*/
    /*-----------------------------------------------------------------------*/

    private static final String $jaxxObjectDescriptor = "H4sIAAAAAAAAAJVTv28TMRj9cjRJkwAFIqoCBbUlK5eqGwqCQqOooPBDpENFljqx1Vzl+Izto5cF8SfwJ8DOgsTGhBiYGVgQ/wJCDKyIz05yScoh4Ia7kz+/9z0/v+/VV8hqBasHJI59FQkT9Jl/5+bu7v3OAeuaOtNdFUgTKhg+GQ+8NpRosq4NXG43Lbw6gle3wr4MBRNT6FoTitoMONM9xoyBi7OIrtbVVlKuxTJSY9ZEVBrri+/fvOf02UsPIJaobg6PsvI31OQkc03wAmrgDHZ6QqqciH2UoQKxj3pP2LUtTrS+R/rsMTyFfBNykigkM7D270d2HA4fSwOlSp31wwdEML5uYMOJpbjid8cUvltjNEAS/xYjoh5GHc6agTYWKqUjyxnI94ignCkDV/+fZnuInWKr7BCso6ilGQf1Ifrhu5rdWUgARZoQGriSghn17mDvIwIsw4LEy7owA8MY+JMYTO4p04asinAZtbV/T85DLA0zs3QkM5bQVX8ulj+9/fKmMQ6Kh73Ppm6dyjleoFShRIMD23phmJLIBLx6l8haGwqacRwSNwTLKcJaozKKw36nLdy3cH+b6B5SZPOf371f3Pt4DLwGFHlIaIPY/behYHoKXQg5jeWNTafo+OE8vk9ZbQZynAzCCH0/eY0SQ1Y6gaBo+fUYTVhOMSFR0il8+FFuvd4cG5FBYef+uH1iRvYR5ALBA8HczIzGIXVGSlKziIaT2KcNQsZ+i3IUv/PufSntpPM2PjsD6dhX48h+1pxw+1dxPGXk+QVItzAyyQQAAA==";
    private static final Log log = LogFactory.getLog(BeanDoubleListDemo.class);
    private static final long serialVersionUID = 1L;

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Internal states ---------------------------*/
    /*-----------------------------------------------------------------------*/

    private boolean allComponentsCreated;

    /*-----------------------------------------------------------------------*/
    /*------------------------ Protected components  ------------------------*/
    /*-----------------------------------------------------------------------*/

    protected BeanDoubleList<People> doubleList;
    protected BeanDoubleListDemoHandler handler;

    /*-----------------------------------------------------------------------*/
    /*------------------------- Private components  -------------------------*/
    /*-----------------------------------------------------------------------*/

    private BeanDoubleListDemo $DemoPanel0 = this;
    private Table $Table0;

    /*-----------------------------------------------------------------------*/
    /*---------------------- Raw body code from script ----------------------*/
    /*-----------------------------------------------------------------------*/

    protected void $afterCompleteSetup() {
        handler.init();
    }
    
    @Override
    protected String[] getSources() {
        return new String[]{
          getDefaultSource(),
          "BeanDoubleListDemoHandler.java",
        };
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Constructors  ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public BeanDoubleListDemo(LayoutManager param0) {
        super(param0);
        $initialize();
    }

    public BeanDoubleListDemo(JAXXContext param0, LayoutManager param1) {
        super(param0 ,param1);
        $initialize();
    }

    public BeanDoubleListDemo(LayoutManager param0, boolean param1) {
        super(param0 ,param1);
        $initialize();
    }

    public BeanDoubleListDemo(JAXXContext param0, LayoutManager param1, boolean param2) {
        super(param0 ,param1 ,param2);
        $initialize();
    }

    public BeanDoubleListDemo() {
        $initialize();
    }

    public BeanDoubleListDemo(JAXXContext param0) {
        super(param0);
        $initialize();
    }

    public BeanDoubleListDemo(boolean param0) {
        super(param0);
        $initialize();
    }

    public BeanDoubleListDemo(JAXXContext param0, boolean param1) {
        super(param0 ,param1);
        $initialize();
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Statics methods ---------------------------*/
    /*-----------------------------------------------------------------------*/

    public static JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return JAXXUtil.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*-----------------------------------------------------------------------*/
    /*----------------------- Public acessor methods  -----------------------*/
    /*-----------------------------------------------------------------------*/

    public BeanDoubleList<People> getDoubleList() {
        return doubleList;
    }

    public BeanDoubleListDemoHandler getHandler() {
        return handler;
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Protected acessors methods  ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected Table get$Table0() {
        return $Table0;
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Components creation methods ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected void createDoubleList() {
        $objectMap.put("doubleList", doubleList = new BeanDoubleList<People>());
        
        doubleList.setName("doubleList");
    }

    protected void createHandler() {
        $objectMap.put("handler", handler = new BeanDoubleListDemoHandler(this));
    }

    /*-----------------------------------------------------------------------*/
    /*------------------------ Internal jaxx methods ------------------------*/
    /*-----------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
        // inline complete setup of $DemoPanel0
        add($Table0);
        // inline complete setup of $Table0
        $Table0.add(doubleList, new GridBagConstraints(0, 0, 1, 1, 1.0, 1.0, 10, 1, new Insets(3, 3, 3, 3), 0, 0));
        
        // apply 2 property setters
        doubleList.setBeanType(People.class);
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated) {
            return;
        }
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
        $objectMap.put("$DemoPanel0", $DemoPanel0);
        createHandler();
        // inline creation of $Table0
        $objectMap.put("$Table0", $Table0 = new Table());
        
        $Table0.setName("$Table0");
        createDoubleList();
        // inline creation of $DemoPanel0
        setName("$DemoPanel0");
        setLayout(new BorderLayout());
        
        $completeSetup();
    }

}
